@@ -1,68 +1,68 @@
 <?xml version="1.0" encoding="utf-8"?>
 <!DOCTYPE TS>
-<TS version="2.1" language="uk">
+<TS version="2.1" language="uk_UA">
 <context>
     <name>EffectSRConverterFactory</name>
     <message>
         <location filename="../effectsrconverterfactory.cpp" line="30"/>
         <source>SRC Plugin</source>
-        <translation>Модуль SRC</translation>
+        <translation>Втулок SRC</translation>
+    </message>
+    <message>
+        <location filename="../effectsrconverterfactory.cpp" line="50"/>
+        <source>About Sample Rate Converter Plugin</source>
+        <translation>Про втулок Sample Rate Converter</translation>
     </message>
     <message>
         <location filename="../effectsrconverterfactory.cpp" line="51"/>
-        <source>About Sample Rate Converter Plugin</source>
-        <translation>Про модуль Sample Rate Converter</translation>
+        <source>Qmmp Sample Rate Converter Plugin</source>
+        <translation>Втулок Sample Rate Converter для Qmmp</translation>
     </message>
     <message>
         <location filename="../effectsrconverterfactory.cpp" line="52"/>
-        <source>Qmmp Sample Rate Converter Plugin</source>
-        <translation>Модуль Sample Rate Converter для Qmmp</translation>
-    </message>
-    <message>
-        <location filename="../effectsrconverterfactory.cpp" line="53"/>
         <source>Written by: Ilya Kotov &lt;forkotov02@ya.ru&gt;</source>
         <translation>Розробник: Ілля Котов &lt;forkotov02@ya.ru&gt;</translation>
     </message>
 </context>
 <context>
-    <name>SettingsDialog</name>
+    <name>SRConverterSettingsDialog</name>
     <message>
-        <location filename="../settingsdialog.ui" line="13"/>
+        <location filename="../srconvertersettingsdialog.ui" line="14"/>
         <source>Sample Rate Converter Plugin Settings</source>
-        <translation>Налаштування модуля Sample Rate Converter</translation>
+        <translation>Налаштування втулка Sample Rate Converter</translation>
     </message>
     <message>
-        <location filename="../settingsdialog.ui" line="19"/>
+        <location filename="../srconvertersettingsdialog.ui" line="20"/>
         <source>Sample Rate (Hz):</source>
-        <translation>Дискретизація семпла (Гц):</translation>
+        <translation>Дискретизація семплу (Гц):</translation>
     </message>
     <message>
-        <location filename="../settingsdialog.ui" line="39"/>
+        <location filename="../srconvertersettingsdialog.ui" line="40"/>
         <source>Interpolation Engine:</source>
         <translation>Технологія інтерполяції:</translation>
     </message>
     <message>
-        <location filename="../settingsdialog.ui" line="47"/>
+        <location filename="../srconvertersettingsdialog.ui" line="48"/>
         <source>Best Sinc Interpolation</source>
         <translation>Кращий синк інтерполяції</translation>
     </message>
     <message>
-        <location filename="../settingsdialog.ui" line="52"/>
+        <location filename="../srconvertersettingsdialog.ui" line="53"/>
         <source>Medium Sinc Interpolation</source>
         <translation>Середній синк інтерполяції</translation>
     </message>
     <message>
-        <location filename="../settingsdialog.ui" line="57"/>
+        <location filename="../srconvertersettingsdialog.ui" line="58"/>
         <source>Fastest Sinc Interpolation</source>
         <translation>Найшвидший синк інтерполяції</translation>
     </message>
     <message>
-        <location filename="../settingsdialog.ui" line="62"/>
+        <location filename="../srconvertersettingsdialog.ui" line="63"/>
         <source>ZOH Interpolation</source>
         <translation>Інтерполяція ZOH</translation>
     </message>
     <message>
-        <location filename="../settingsdialog.ui" line="67"/>
+        <location filename="../srconvertersettingsdialog.ui" line="68"/>
         <source>Linear Interpolation</source>
         <translation>Лінійна інтерполяція</translation>
     </message>
