@@ -1,5 +1,5 @@
 /***************************************************************************
- *   Copyright (C) 2008-2019 by Ilya Kotov                                 *
+ *   Copyright (C) 2008-2025 by Ilya Kotov                                 *
  *   forkotov02@ya.ru                                                      *
  *                                                                         *
  *   This program is free software; you can redistribute it and/or modify  *
@@ -49,8 +49,8 @@ FFmpegEngine::FFmpegEngine(EngineFactory *factory, QObject *parent)
     m_videoWindow = new VideoWindow(qApp->activeWindow());
     m_decoder = nullptr;
     reset();
-    connect(m_videoWindow, SIGNAL(resizeRequest(QSize)), m_videoThread, SLOT(setWindowSize(QSize)));
-    connect(m_videoWindow, SIGNAL(stopRequest()), SLOT(onStopRequest()));
+    connect(m_videoWindow, &VideoWindow::resizeRequest, m_videoThread, &VideoThread::setWindowSize);
+    connect(m_videoWindow, &VideoWindow::stopRequest, this, &FFmpegEngine::onStopRequest);
 }
 
 FFmpegEngine::~FFmpegEngine()
@@ -81,7 +81,7 @@ bool FFmpegEngine::play()
 
 bool FFmpegEngine::enqueue(InputSource *source)
 {
-    if(!QDir::match(m_factory->properties().filters, source->path().section(QChar('/'), -1)))
+    if(!QDir::match(m_factory->properties().filters, source->path().section(QLatin1Char('/'), -1)))
         return false;
 
     FFVideoDecoder *decoder = new FFVideoDecoder();
@@ -117,7 +117,7 @@ void FFmpegEngine::seek(qint64 pos)
 
 void FFmpegEngine::stop()
 {
-    qDebug("%s", Q_FUNC_INFO);
+    qCDebug(plugin) << Q_FUNC_INFO;
     mutex()->lock ();
     m_user_stop = true;
     mutex()->unlock();
@@ -357,7 +357,7 @@ void FFmpegEngine::run()
     if(m_finish && !m_user_stop)
         StateHandler::instance()->sendFinished();
     StateHandler::instance()->dispatch(Qmmp::Stopped);
-    qDebug("FFmpegEngine: thread finished");
+    qCDebug(plugin) << "thread finished";
 }
 
 void FFmpegEngine::sendMetaData()
