@@ -1,5 +1,5 @@
 /***************************************************************************
- *   Copyright (C) 2008-2021 by Ilya Kotov                                 *
+ *   Copyright (C) 2008-2025 by Ilya Kotov                                 *
  *   forkotov02@ya.ru                                                      *
  *                                                                         *
  *   This program is free software; you can redistribute it and/or modify  *
@@ -21,7 +21,6 @@
 #include <QMessageBox>
 #include <QtPlugin>
 #include <QDir>
-#include "ffvideofactory.h"
 #include "ffmpegengine.h"
 #include "ffvideometadatamodel.h"
 #include "ffvideofactory.h"
@@ -40,12 +39,12 @@ EngineProperties FFVideoFactory::properties() const
 {
     EngineProperties properties;
     properties.name = tr("FFmpeg Video Plugin");
-    properties.shortName = "ffvideo";
-    properties.filters = QStringList { "*.avi", "*.mpg", "*.mpeg", "*.divx", "*.qt",
-            "*.mov", "*.wmv", "*.asf", "*.flv", "*.3gp", "*.mkv", "*.mp4", "*.webm" };
+    properties.shortName = "ffvideo"_L1;
+    properties.filters = QStringList { u"*.avi"_s, u"*.mpg"_s, u"*.mpeg"_s, u"*.divx"_s, u"*.qt"_s,
+            u"*.mov"_s, u"*.wmv"_s, u"*.asf"_s, u"*.flv"_s, u"*.3gp"_s, u"*.mkv"_s, u"*.mp4"_s, u"*.webm"_s };
     properties.description = tr("Video Files");
     //properties.contentType = "application/ogg;audio/x-vorbis+ogg";
-    properties.protocols = QStringList { "file" };
+    properties.protocols = QStringList { u"file"_s };
     properties.hasAbout = true;
     properties.hasSettings = false;
     return properties;
@@ -53,7 +52,7 @@ EngineProperties FFVideoFactory::properties() const
 
 bool FFVideoFactory::supports(const QString &source) const
 {
-    return QDir::match(properties().filters, source.section(QChar('/'), -1));
+    return QDir::match(properties().filters, source.section(QLatin1Char('/'), -1));
 }
 
 AbstractEngine *FFVideoFactory::create(QObject *parent)
@@ -76,7 +75,7 @@ QList<TrackInfo *> FFVideoFactory::createPlayList(const QString &path, TrackInfo
     if(avformat_open_input(&in, path.toLocal8Bit().constData(), nullptr, nullptr) < 0)
 #endif
     {
-        qDebug("DecoderFFmpegFactory: unable to open file");
+        qCDebug(plugin) << "unable to open file";
         delete info;
         return  QList<TrackInfo*>();
     }
@@ -129,7 +128,12 @@ QList<TrackInfo *> FFVideoFactory::createPlayList(const QString &path, TrackInfo
             AVCodecParameters *c = in->streams[idx]->codecpar;
             info->setValue(Qmmp::BITRATE, int(c->bit_rate) / 1000);
             info->setValue(Qmmp::SAMPLERATE, c->sample_rate);
+#if (LIBAVCODEC_VERSION_INT >= AV_VERSION_INT(59,37,100)) //ffmpeg-5.1
+            info->setValue(Qmmp::CHANNELS, c->ch_layout.nb_channels);
+#else
             info->setValue(Qmmp::CHANNELS, c->channels);
+#endif
+
             info->setValue(Qmmp::BITS_PER_SAMPLE, c->bits_per_raw_sample);
 
             //info->setValue(Qmmp::FORMAT_NAME, QString::fromLatin1(avcodec_get_name(c->codec_id)));
@@ -147,24 +151,25 @@ MetaDataModel* FFVideoFactory::createMetaDataModel(const QString &path, bool rea
     return new FFVideoMetaDataModel(path);
 }
 
-void FFVideoFactory::showSettings(QWidget *)
-{}
+QDialog *FFVideoFactory::createSettings(QWidget *)
+{
+    return nullptr;
+}
 
 void FFVideoFactory::showAbout(QWidget *parent)
 {
-    QMessageBox::about (parent, tr("About FFVideo Plugin"),
-                        tr("FFmpeg-based video plugin for Qmmp")+"\n"+
-                        tr("Compiled against:") + "\n"+
-                        QString("libavformat-%1\n"
-                                "libavcodec-%2\n"
-                                "libavutil-%3\n"
-                                "libswscale-%4")
-                        .arg(AV_STRINGIFY(LIBAVFORMAT_VERSION))
-                        .arg(AV_STRINGIFY(LIBAVCODEC_VERSION))
-                        .arg(AV_STRINGIFY(LIBAVUTIL_VERSION))
-                        .arg(AV_STRINGIFY(LIBSWSCALE_VERSION))
-                        +"\n"+
-                        tr("Written by: Ilya Kotov <forkotov02@ya.ru>"));
+    QMessageBox::about(parent, tr("About FFVideo Plugin"),
+                       tr("FFmpeg-based video plugin for Qmmp") + QChar::LineFeed +
+                       tr("Compiled against:") + QChar::LineFeed +
+                       QStringLiteral("libavformat-%1\n"
+                                      "libavcodec-%2\n"
+                                      "libavutil-%3\n"
+                                      "libswscale-%4")
+                       .arg(QString::fromLatin1(AV_STRINGIFY(LIBAVFORMAT_VERSION)),
+                            QString::fromLatin1(AV_STRINGIFY(LIBAVCODEC_VERSION)),
+                            QString::fromLatin1(AV_STRINGIFY(LIBAVUTIL_VERSION)),
+                            QString::fromLatin1(AV_STRINGIFY(LIBSWSCALE_VERSION))) + QChar::LineFeed +
+                       tr("Written by: Ilya Kotov <forkotov02@ya.ru>"));
 }
 
 QString FFVideoFactory::translation() const
