@@ -4,32 +4,32 @@
 <context>
     <name>FFVideoFactory</name>
     <message>
-        <location filename="../ffvideofactory.cpp" line="42"/>
+        <location filename="../ffvideofactory.cpp" line="41"/>
         <source>FFmpeg Video Plugin</source>
         <translation>Suplemento FFmpeg Video</translation>
     </message>
     <message>
-        <location filename="../ffvideofactory.cpp" line="46"/>
+        <location filename="../ffvideofactory.cpp" line="45"/>
         <source>Video Files</source>
         <translation>Ficheiros de vídeo</translation>
     </message>
     <message>
-        <location filename="../ffvideofactory.cpp" line="155"/>
+        <location filename="../ffvideofactory.cpp" line="161"/>
         <source>About FFVideo Plugin</source>
         <translation>Acerca de suplemento FFVideo</translation>
     </message>
     <message>
-        <location filename="../ffvideofactory.cpp" line="156"/>
+        <location filename="../ffvideofactory.cpp" line="162"/>
         <source>FFmpeg-based video plugin for Qmmp</source>
         <translation>Suplemento FFmpeg Video para o Qmmp</translation>
     </message>
     <message>
-        <location filename="../ffvideofactory.cpp" line="157"/>
+        <location filename="../ffvideofactory.cpp" line="163"/>
         <source>Compiled against:</source>
         <translation>Compilado com:</translation>
     </message>
     <message>
-        <location filename="../ffvideofactory.cpp" line="167"/>
+        <location filename="../ffvideofactory.cpp" line="172"/>
         <source>Written by: Ilya Kotov &lt;forkotov02@ya.ru&gt;</source>
         <translation>Desenvolvido por: Ilya Kotov &lt;forkotov02@ya.ru&gt;</translation>
     </message>
@@ -49,7 +49,7 @@
     <message>
         <location filename="../ffvideometadatamodel.cpp" line="70"/>
         <source>Audio bitrate</source>
-        <translation>Taxa de dados do áudio</translation>
+        <translation>Taxa de dados de áudio</translation>
     </message>
     <message>
         <location filename="../ffvideometadatamodel.cpp" line="71"/>
@@ -64,7 +64,7 @@
     <message>
         <location filename="../ffvideometadatamodel.cpp" line="51"/>
         <location filename="../ffvideometadatamodel.cpp" line="70"/>
-        <location filename="../ffvideometadatamodel.cpp" line="79"/>
+        <location filename="../ffvideometadatamodel.cpp" line="83"/>
         <source>kbps</source>
         <translation>kbps</translation>
     </message>
@@ -74,17 +74,18 @@
         <translation>Hz</translation>
     </message>
     <message>
-        <location filename="../ffvideometadatamodel.cpp" line="72"/>
+        <location filename="../ffvideometadatamodel.cpp" line="73"/>
+        <location filename="../ffvideometadatamodel.cpp" line="75"/>
         <source>Audio channels</source>
         <translation>Canais de áudio</translation>
     </message>
     <message>
-        <location filename="../ffvideometadatamodel.cpp" line="78"/>
+        <location filename="../ffvideometadatamodel.cpp" line="82"/>
         <source>Video size</source>
         <translation>Tamanho do vídeo</translation>
     </message>
     <message>
-        <location filename="../ffvideometadatamodel.cpp" line="79"/>
+        <location filename="../ffvideometadatamodel.cpp" line="83"/>
         <source>Video bitrate</source>
         <translation>Taxa de dados do vídeo</translation>
     </message>
@@ -97,32 +98,38 @@
         <translation>FFmpeg Video</translation>
     </message>
     <message>
-        <location filename="../videowindow.cpp" line="45"/>
+        <location filename="../videowindow.cpp" line="46"/>
+        <location filename="../videowindow.cpp" line="51"/>
         <source>&amp;Pause</source>
         <translation>&amp;Pausa</translation>
     </message>
     <message>
-        <location filename="../videowindow.cpp" line="45"/>
+        <location filename="../videowindow.cpp" line="46"/>
+        <location filename="../videowindow.cpp" line="51"/>
         <source>Space</source>
         <translation>Espaço</translation>
     </message>
     <message>
-        <location filename="../videowindow.cpp" line="46"/>
+        <location filename="../videowindow.cpp" line="47"/>
+        <location filename="../videowindow.cpp" line="52"/>
         <source>&amp;Stop</source>
         <translation>Pa&amp;rar</translation>
     </message>
     <message>
-        <location filename="../videowindow.cpp" line="46"/>
+        <location filename="../videowindow.cpp" line="47"/>
+        <location filename="../videowindow.cpp" line="52"/>
         <source>V</source>
         <translation>V</translation>
     </message>
     <message>
-        <location filename="../videowindow.cpp" line="48"/>
+        <location filename="../videowindow.cpp" line="49"/>
+        <location filename="../videowindow.cpp" line="54"/>
         <source>&amp;Fullscreen</source>
         <translation>&amp;Ecrã completo</translation>
     </message>
     <message>
-        <location filename="../videowindow.cpp" line="48"/>
+        <location filename="../videowindow.cpp" line="49"/>
+        <location filename="../videowindow.cpp" line="54"/>
         <source>F</source>
         <translation>F</translation>
     </message>
