@@ -4,32 +4,32 @@
 <context>
     <name>FFVideoFactory</name>
     <message>
-        <location filename="../ffvideofactory.cpp" line="42"/>
+        <location filename="../ffvideofactory.cpp" line="41"/>
         <source>FFmpeg Video Plugin</source>
         <translation>FFmpeg Vidyo Eklentisi</translation>
     </message>
     <message>
-        <location filename="../ffvideofactory.cpp" line="46"/>
+        <location filename="../ffvideofactory.cpp" line="45"/>
         <source>Video Files</source>
         <translation>Vidyo Dosyaları</translation>
     </message>
     <message>
-        <location filename="../ffvideofactory.cpp" line="155"/>
+        <location filename="../ffvideofactory.cpp" line="161"/>
         <source>About FFVideo Plugin</source>
         <translation>FFmpeg Vidyo Eklentisi Hakkında</translation>
     </message>
     <message>
-        <location filename="../ffvideofactory.cpp" line="156"/>
+        <location filename="../ffvideofactory.cpp" line="162"/>
         <source>FFmpeg-based video plugin for Qmmp</source>
         <translation>Qmmp için FFmpeg tabanlı vidyo eklentisi</translation>
     </message>
     <message>
-        <location filename="../ffvideofactory.cpp" line="157"/>
+        <location filename="../ffvideofactory.cpp" line="163"/>
         <source>Compiled against:</source>
-        <translation>Dayanarak derlendi:</translation>
+        <translation>Dayanarak derlendi</translation>
     </message>
     <message>
-        <location filename="../ffvideofactory.cpp" line="167"/>
+        <location filename="../ffvideofactory.cpp" line="172"/>
         <source>Written by: Ilya Kotov &lt;forkotov02@ya.ru&gt;</source>
         <translation>Yazan: Ilya Kotov &lt;forkotov02@ya.ru&gt;</translation>
     </message>
@@ -64,7 +64,7 @@
     <message>
         <location filename="../ffvideometadatamodel.cpp" line="51"/>
         <location filename="../ffvideometadatamodel.cpp" line="70"/>
-        <location filename="../ffvideometadatamodel.cpp" line="79"/>
+        <location filename="../ffvideometadatamodel.cpp" line="83"/>
         <source>kbps</source>
         <translation>kbps</translation>
     </message>
@@ -74,17 +74,18 @@
         <translation>Hz</translation>
     </message>
     <message>
-        <location filename="../ffvideometadatamodel.cpp" line="72"/>
+        <location filename="../ffvideometadatamodel.cpp" line="73"/>
+        <location filename="../ffvideometadatamodel.cpp" line="75"/>
         <source>Audio channels</source>
         <translation>Ses kanalları</translation>
     </message>
     <message>
-        <location filename="../ffvideometadatamodel.cpp" line="78"/>
+        <location filename="../ffvideometadatamodel.cpp" line="82"/>
         <source>Video size</source>
         <translation>Vidyo Boyutu</translation>
     </message>
     <message>
-        <location filename="../ffvideometadatamodel.cpp" line="79"/>
+        <location filename="../ffvideometadatamodel.cpp" line="83"/>
         <source>Video bitrate</source>
         <translation>Vidyo bit hızı</translation>
     </message>
@@ -97,32 +98,38 @@
         <translation>FFmpeg Vidyo</translation>
     </message>
     <message>
-        <location filename="../videowindow.cpp" line="45"/>
+        <location filename="../videowindow.cpp" line="46"/>
+        <location filename="../videowindow.cpp" line="51"/>
         <source>&amp;Pause</source>
         <translation>&amp;Duraklat</translation>
     </message>
     <message>
-        <location filename="../videowindow.cpp" line="45"/>
+        <location filename="../videowindow.cpp" line="46"/>
+        <location filename="../videowindow.cpp" line="51"/>
         <source>Space</source>
         <translation>Boşluk</translation>
     </message>
     <message>
-        <location filename="../videowindow.cpp" line="46"/>
+        <location filename="../videowindow.cpp" line="47"/>
+        <location filename="../videowindow.cpp" line="52"/>
         <source>&amp;Stop</source>
         <translation>&amp;Durdur</translation>
     </message>
     <message>
-        <location filename="../videowindow.cpp" line="46"/>
+        <location filename="../videowindow.cpp" line="47"/>
+        <location filename="../videowindow.cpp" line="52"/>
         <source>V</source>
         <translation>V</translation>
     </message>
     <message>
-        <location filename="../videowindow.cpp" line="48"/>
+        <location filename="../videowindow.cpp" line="49"/>
+        <location filename="../videowindow.cpp" line="54"/>
         <source>&amp;Fullscreen</source>
         <translation>&amp;Tam Ekran</translation>
     </message>
     <message>
-        <location filename="../videowindow.cpp" line="48"/>
+        <location filename="../videowindow.cpp" line="49"/>
+        <location filename="../videowindow.cpp" line="54"/>
         <source>F</source>
         <translation>F</translation>
     </message>
