@@ -1,5 +1,5 @@
 /***************************************************************************
- *   Copyright (C) 2011-2021 by Ilya Kotov                                 *
+ *   Copyright (C) 2011-2025 by Ilya Kotov                                 *
  *   forkotov02@ya.ru                                                      *
  *                                                                         *
  *   This program is free software; you can redistribute it and/or modify  *
@@ -34,31 +34,22 @@ DecoderFFapCUE::DecoderFFapCUE(const QString &url) : Decoder(),
 
 DecoderFFapCUE::~DecoderFFapCUE()
 {
-    if(m_decoder)
-        delete m_decoder;
-    m_decoder = nullptr;
-    if(m_parser)
-        delete m_parser;
-    m_parser = nullptr;
-    if(m_buf)
-        delete [] m_buf;
-    m_buf = nullptr;
+    delete m_decoder;
+    delete m_parser;
+    delete [] m_buf;
     if(m_input)
         m_input->deleteLater();
-    m_input = nullptr;
 }
 
 bool DecoderFFapCUE::initialize()
 {
-    QString filePath = m_url;
-    if(!m_url.startsWith("ape://") || filePath.endsWith(".ape"))
+    if(!m_url.startsWith(u"ape://"_s, Qt::CaseInsensitive) || m_url.endsWith(u".ape"_s, Qt::CaseInsensitive))
     {
-        qWarning("DecoderFFapCUE: invalid url.");
+        qCWarning(plugin) << "invalid url.";
         return false;
     }
-    filePath.remove("ape://");
-    filePath.remove(QRegularExpression("#\\d+$"));
-    m_track = m_url.section("#", -1).toInt();
+
+    QString filePath = TrackInfo::pathFromUrl(m_url, &m_track);
 
     TagLib::FileStream stream(QStringToFileName(filePath), true);
     TagLib::APE::File file(&stream);
@@ -67,23 +58,23 @@ bool DecoderFFapCUE::initialize()
 
     if(!tag || !tag->itemListMap().contains("CUESHEET"))
     {
-        qWarning("DecoderFFapCUE: unable to find cuesheet comment.");
+        qCWarning(plugin) << "unable to find cuesheet comment.";
         return false;
     }
 
     m_parser = new CueParser(tag->itemListMap()["CUESHEET"].toString().toCString(true));
     m_parser->setDuration(file.audioProperties()->lengthInMilliseconds());
-    m_parser->setUrl("ape", filePath);
+    m_parser->setUrl(u"ape"_s, filePath);
 
     if(m_track > m_parser->count() || m_parser->isEmpty())
     {
-        qWarning("DecoderFFapCUE: invalid cuesheet");
+        qCWarning(plugin) << "invalid cuesheet";
         return false;
     }
     m_input = new QFile(filePath);
     if(!m_input->open(QIODevice::ReadOnly))
     {
-        qWarning("DecoderFFapCUE: %s", qPrintable(m_input->errorString()));
+        qCWarning(plugin) << "%s" << m_input->errorString();
         return false;
     }
     QMap<Qmmp::MetaData, QString> metaData = m_parser->info(m_track)->metaData();
@@ -95,7 +86,7 @@ bool DecoderFFapCUE::initialize()
     m_decoder = new DecoderFFap(filePath, m_input);
     if(!m_decoder->initialize())
     {
-        qWarning("DecoderFFapCUE: invalid audio file");
+        qCWarning(plugin) << "invalid audio file";
         return false;
     }
     m_decoder->seek(m_offset);
@@ -165,8 +156,7 @@ qint64 DecoderFFapCUE::read(unsigned char *data, qint64 size)
     len2 = (len2 / m_frameSize) * m_frameSize; //whole of samples of each channel
     m_written += len2;
     //save data of the next track
-    if(m_buf)
-        delete[] m_buf;
+    delete[] m_buf;
     m_buf_size = len - len2;
     m_buf = new char[m_buf_size];
     memmove(m_buf, data + len2, m_buf_size);
@@ -182,8 +172,8 @@ const QString DecoderFFapCUE::nextURL() const
 {
     if(m_track +1 <= m_parser->count())
         return m_parser->url(m_track + 1);
-    else
-        return QString();
+
+    return QString();
 }
 
 void DecoderFFapCUE::next()
