@@ -16,12 +16,12 @@
     <message>
         <location filename="../decoderffapfactory.cpp" line="150"/>
         <source>About FFap Audio Plugin</source>
-        <translation>tietoja: FFap Audio Plugin</translation>
+        <translation>Tietoja: FFap Audio Plugin</translation>
     </message>
     <message>
         <location filename="../decoderffapfactory.cpp" line="151"/>
         <source>Qmmp FFap Audio Plugin</source>
-        <translation>Qmmp:n FFap-ääniliitännäinen</translation>
+        <translation>Qmmp FFap Audio Plugin</translation>
     </message>
     <message>
         <location filename="../decoderffapfactory.cpp" line="152"/>
@@ -42,12 +42,12 @@
 <context>
     <name>FFapMetaDataModel</name>
     <message>
-        <location filename="../ffapmetadatamodel.cpp" line="65"/>
+        <location filename="../ffapmetadatamodel.cpp" line="62"/>
         <source>Samples</source>
         <translation>Samplet</translation>
     </message>
     <message>
-        <location filename="../ffapmetadatamodel.cpp" line="66"/>
+        <location filename="../ffapmetadatamodel.cpp" line="63"/>
         <source>Version</source>
         <translation>Versio</translation>
     </message>
