@@ -6,48 +6,48 @@
     <message>
         <location filename="../ytbinputfactory.cpp" line="36"/>
         <source>Youtube Plugin</source>
-        <translation>Youtube-liitännäinen</translation>
+        <translation>Youtube Plugin</translation>
     </message>
     <message>
-        <location filename="../ytbinputfactory.cpp" line="69"/>
+        <location filename="../ytbinputfactory.cpp" line="70"/>
         <source>About Youtube Transport Plugin</source>
         <translation>Tietoja: Youtube Transport Plugin</translation>
     </message>
     <message>
-        <location filename="../ytbinputfactory.cpp" line="70"/>
+        <location filename="../ytbinputfactory.cpp" line="71"/>
         <source>Qmmp Youtube Transport Plugin</source>
         <translation>Qmmp Youtube Transport Plugin</translation>
     </message>
     <message>
-        <location filename="../ytbinputfactory.cpp" line="71"/>
+        <location filename="../ytbinputfactory.cpp" line="72"/>
         <source>This plugin adds feature to play audio from Youtube using %1 utility</source>
         <translation>Laajennus lisää ominaisuuden toistaa Youtube ääntä käyttämällä %1 ohjelmaa</translation>
     </message>
     <message>
-        <location filename="../ytbinputfactory.cpp" line="73"/>
+        <location filename="../ytbinputfactory.cpp" line="74"/>
         <source>%1 version: %2</source>
         <translation>%1 versio: %2</translation>
     </message>
     <message>
-        <location filename="../ytbinputfactory.cpp" line="74"/>
+        <location filename="../ytbinputfactory.cpp" line="75"/>
         <source>Written by: Ilya Kotov &amp;lt;forkotov02@ya.ru&amp;gt;</source>
         <translation>Kirjoittanut: Ilya Kotov &amp;lt;forkotov02@ya.ru&amp;gt;</translation>
     </message>
 </context>
 <context>
     <name>YtbInputSource</name>
-    <message>
-        <location filename="../ytbinputsource.cpp" line="184"/>
-        <source>Uploader</source>
-        <translation>Lähettäjä</translation>
-    </message>
     <message>
         <location filename="../ytbinputsource.cpp" line="185"/>
-        <source>Upload date</source>
-        <translation>Lähetyspäivä</translation>
+        <source>Uploader</source>
+        <translation>Lataaja</translation>
     </message>
     <message>
         <location filename="../ytbinputsource.cpp" line="186"/>
+        <source>Upload date</source>
+        <translation>Latauspäivä</translation>
+    </message>
+    <message>
+        <location filename="../ytbinputsource.cpp" line="187"/>
         <source>Duration</source>
         <translation>Kesto</translation>
     </message>
