@@ -1,5 +1,5 @@
 /***************************************************************************
- *   Copyright (C) 2019-2021 by Ilya Kotov                                 *
+ *   Copyright (C) 2019-2025 by Ilya Kotov                                 *
  *   forkotov02@ya.ru                                                      *
  *                                                                         *
  *   This program is free software; you can redistribute it and/or modify  *
@@ -28,13 +28,13 @@
 InputSourceProperties YtbInputFactory::properties() const
 {
     InputSourceProperties properties;
-    properties.protocols = QStringList { "ytb" };
+    properties.protocols = QStringList { u"ytb"_s };
     properties.regExps = QList<QRegularExpression> {
-            QRegularExpression("^https\\:\\/\\/www.youtube.com\\/.*"),
-            QRegularExpression("^https\\:\\/\\/youtu.be\\/.*")
+            QRegularExpression(u"^https\\:\\/\\/www.youtube.com\\/.*"_s),
+            QRegularExpression(u"^https\\:\\/\\/youtu.be\\/.*"_s)
     };
     properties.name = tr("Youtube Plugin");
-    properties.shortName = "ytb";
+    properties.shortName = "ytb"_L1;
     properties.hasAbout = true;
     properties.hasSettings = false;
     return properties;
@@ -45,32 +45,33 @@ InputSource *YtbInputFactory::create(const QString &url, QObject *parent)
     return new YtbInputSource(url, parent);
 }
 
-void YtbInputFactory::showSettings(QWidget *parent)
+QDialog *YtbInputFactory::createSettings(QWidget *parent)
 {
     Q_UNUSED(parent);
+    return nullptr;
 }
 
 void YtbInputFactory::showAbout(QWidget *parent)
 {
     QString version;
     QString backend = YtbInputSource::findBackend(&version);
-    QString backendName = QString("<b>%1</b>").arg(backend);
+    QString backendName = QStringLiteral("<b>%1</b>").arg(backend);
     if(backend.isEmpty() || version.isEmpty())
     {
-        qWarning("YtbInputFactory: unable to find backend");
+        qCWarning(plugin) << "unable to find backend";
         return;
     }
 
     if(backend == QLatin1String("yt-dlp"))
-        backendName = QLatin1String("<a href=\"https://github.com/yt-dlp/yt-dlp\">yt-dlp</a>");
+        backendName = QStringLiteral("<a href=\"https://github.com/yt-dlp/yt-dlp\">yt-dlp</a>");
     else if(backend == QLatin1String("youtube-dl"))
-        backendName = QLatin1String("<a href=\"https://youtube-dl.org\">youtube-dl</a>");
+        backendName = QStringLiteral("<a href=\"https://youtube-dl.org\">youtube-dl</a>");
 
     QMessageBox::about(parent, tr("About Youtube Transport Plugin"),
-                       tr("Qmmp Youtube Transport Plugin") + "<br>" +
+                       tr("Qmmp Youtube Transport Plugin") + QStringLiteral("<br>") +
                        tr("This plugin adds feature to play audio from Youtube using %1 "
-                          "utility").arg(backendName) + "<br>" +
-                       tr("%1 version: %2").arg(backend).arg(version) + "<br>" +
+                          "utility").arg(backendName) + QStringLiteral("<br>") +
+                       tr("%1 version: %2").arg(backend, version) + QStringLiteral("<br>") +
                        tr("Written by: Ilya Kotov &lt;forkotov02@ya.ru&gt;"));
 }
 
