@@ -1,5 +1,5 @@
 /***************************************************************************
- *   Copyright (C) 2019-2021 by Ilya Kotov                                 *
+ *   Copyright (C) 2019-2025 by Ilya Kotov                                 *
  *   forkotov02@ya.ru                                                      *
  *                                                                         *
  *   This program is free software; you can redistribute it and/or modify  *
@@ -37,9 +37,7 @@ YtbInputSource::YtbInputSource(const QString &url, QObject *parent) : InputSourc
     m_buffer = new BufferDevice(this);
     m_process = new QProcess(this);
     m_manager = new QNetworkAccessManager(this);
-#if (QT_VERSION >= QT_VERSION_CHECK(5, 9, 0))
     m_manager->setRedirectPolicy(QNetworkRequest::NoLessSafeRedirectPolicy);
-#endif
 
     QmmpSettings *gs = QmmpSettings::instance();
     if (gs->isProxyEnabled())
@@ -57,10 +55,10 @@ YtbInputSource::YtbInputSource(const QString &url, QObject *parent) : InputSourc
     else
         m_manager->setProxy(QNetworkProxy::NoProxy);
 
-    connect(m_process, SIGNAL(errorOccurred(QProcess::ProcessError)), SLOT(onProcessErrorOccurred(QProcess::ProcessError)));
-    connect(m_process, SIGNAL(finished(int,QProcess::ExitStatus)), SLOT(onProcessFinished(int,QProcess::ExitStatus)));
-    connect(m_manager, SIGNAL(finished(QNetworkReply*)), SLOT(onFinished(QNetworkReply*)));
-    connect(m_buffer, SIGNAL(seekRequest()), SLOT(onSeekRequest()));
+    connect(m_process, &QProcess::errorOccurred, this, &YtbInputSource::onProcessErrorOccurred);
+    connect(m_process, &QProcess::finished, this, &YtbInputSource::onProcessFinished);
+    connect(m_manager, &QNetworkAccessManager::finished, this, &YtbInputSource::onFinished);
+    connect(m_buffer, &BufferDevice::seekRequest, this, &YtbInputSource::onSeekRequest);
 }
 
 YtbInputSource::~YtbInputSource()
@@ -76,12 +74,12 @@ YtbInputSource::~YtbInputSource()
 
 QString YtbInputSource::findBackend(QString *version)
 {
-    static const QStringList backends = { "yt-dlp", "youtube-dl" };
+    static const QStringList backends = { u"yt-dlp"_s, u"youtube-dl"_s };
 
-    for(const QString &backend : qAsConst(backends))
+    for(const QString &backend : std::as_const(backends))
     {
         QProcess p;
-        p.start(backend, { "--version" });
+        p.start(backend, { u"--version"_s });
         p.waitForFinished();
         if(p.exitCode() == EXIT_SUCCESS)
         {
@@ -104,26 +102,29 @@ bool YtbInputSource::initialize()
     m_backend = findBackend();
     if(m_backend.isEmpty())
     {
-        qWarning("YtbInputSource: unable to find backend");
+        qCWarning(plugin) << "unable to find backend";
         return false;
     }
 
-    qWarning("YtbInputSource: using %s", qPrintable(m_backend));
+    qCWarning(plugin) << "using" << m_backend;
 
     QString id;
-    if(m_url.startsWith("ytb://"))
-        id = m_url.section("://", -1);
-    else if(m_url.startsWith("https://www.youtube.com/"))
-        id = QUrlQuery(QUrl(m_url)).queryItemValue("v");
-    else if(m_url.startsWith("https://youtu.be/"))
-        id = QUrl(m_url).path().remove("/");
+    if(m_url.startsWith(u"ytb://"_s))
+        id = m_url.section(u"://"_s, -1);
+    else if(m_url.startsWith(u"https://www.youtube.com/"_s))
+        id = QUrlQuery(QUrl(m_url)).queryItemValue(u"v"_s);
+    else if(m_url.startsWith(u"https://youtu.be/"_s))
+        id = QUrl(m_url).path().remove(QLatin1Char('/'));
 
-    const QStringList args = { "-j", QString("https://www.youtube.com/watch?v=%1").arg(id) };
+    QStringList args = { u"-j"_s, QStringLiteral("https://www.youtube.com/watch?v=%1").arg(id) };
+
+    if(QmmpSettings::instance()->isProxyEnabled())
+        args << QStringLiteral("--proxy") << QmmpSettings::instance()->proxy().toString();
 
     m_ready = false;
     m_buffer->open(QIODevice::ReadOnly);
     m_process->start(m_backend, args);
-    qDebug("YtbInputSource: starting %s...", qPrintable(m_backend));
+    qCDebug(plugin) << "starting" << m_backend << "...";
     return true;
 }
 
@@ -134,7 +135,7 @@ bool YtbInputSource::isReady() const
 
 bool YtbInputSource::isWaiting() const
 {
-    return !m_ready;
+    return m_getStreamReply && !m_buffer->hasEnougthData();
 }
 
 QString YtbInputSource::contentType() const
@@ -150,7 +151,7 @@ void YtbInputSource::stop()
 
 void YtbInputSource::onProcessErrorOccurred(QProcess::ProcessError)
 {
-    qWarning("YtbInputSource: unable to start process '%s', error: %s", qPrintable(m_backend), qPrintable(m_process->errorString()));
+    qCWarning(plugin, "unable to start process '%s', error: %s", qPrintable(m_backend), qPrintable(m_process->errorString()));
     emit error();
 }
 
@@ -158,7 +159,7 @@ void YtbInputSource::onProcessFinished(int exitCode, QProcess::ExitStatus status
 {
     if(exitCode != EXIT_SUCCESS || status != QProcess::NormalExit)
     {
-        qWarning("YtbInputSource: %s finished with error:\n%s", qPrintable(m_backend), m_process->readAllStandardError().constData());
+        qCWarning(plugin, "%s finished with error:\n%s", qPrintable(m_backend), m_process->readAllStandardError().constData());
         emit error();
         return;
     }
@@ -166,7 +167,7 @@ void YtbInputSource::onProcessFinished(int exitCode, QProcess::ExitStatus status
     QJsonDocument document = QJsonDocument::fromJson(m_process->readAllStandardOutput());
     if(document.isEmpty())
     {
-        qWarning("YtbInputSource: unable to parse %s output", qPrintable(m_backend));
+        qCWarning(plugin, "unable to parse %s output", qPrintable(m_backend));
         emit error();
         return;
     }
@@ -176,80 +177,73 @@ void YtbInputSource::onProcessFinished(int exitCode, QProcess::ExitStatus status
     //qDebug("%s", document.toJson(QJsonDocument::Indented).constData());
 
     QMap<Qmmp::MetaData, QString> metaData = {
-        { Qmmp::TITLE, json["fulltitle"].toString() }
+        { Qmmp::TITLE, json[u"fulltitle"_s].toString() }
     };
     addMetaData(metaData);
 
     QHash<QString, QString> streamInfo = {
-        { tr("Uploader"), json["uploader"].toString() },
-        { tr("Upload date"), json["upload_date"].toString() },
-        { tr("Duration"), QString("%1:%2").arg(json["duration"].toInt() / 60)
-          .arg(json["duration"].toInt() % 60, 2, 10, QChar('0')) },
+        { tr("Uploader"), json[u"uploader"_s].toString() },
+        { tr("Upload date"), json[u"upload_date"_s].toString() },
+        { tr("Duration"), QStringLiteral("%1:%2").arg(json[u"duration"_s].toInt() / 60)
+          .arg(json[u"duration"_s].toInt() % 60, 2, 10, QLatin1Char('0')) },
     };
     addStreamInfo(streamInfo);
 
     double bitrate = 0;
     QString url, codec;
     QJsonObject headers;
-    for(const QJsonValue &value : json["formats"].toArray())
+    for(const QJsonValue &value : json[u"formats"_s].toArray())
     {
         QJsonObject obj = value.toObject();
 
-        qDebug() << obj["acodec"].toString() << obj["vcodec"].toString() << obj["abr"].toDouble();
+        qCDebug(plugin) << obj[u"acodec"_s].toString() << obj[u"vcodec"_s].toString() << obj[u"abr"_s].toDouble();
 
-        if(obj["abr"].toDouble() > bitrate && obj["acodec"].toString() == "opus" && obj["vcodec"].toString() == "none")
+        if(obj[u"abr"_s].toDouble() > bitrate && obj[u"acodec"_s].toString() == "opus"_L1 &&
+                obj[u"vcodec"_s].toString() == "none"_L1)
         {
-            url = obj["protocol"].toString() == "http_dash_segments" ?
-                        obj["fragment_base_url"].toString() : obj["url"].toString();
-
-            bitrate = obj["abr"].toDouble();
-            headers = obj["http_headers"].toObject();
-            codec = obj["acodec"].toString();
-            m_fileSize = obj["filesize"].toInt();
+            url = obj.contains(u"fragment_base_url"_s) ? obj[u"fragment_base_url"_s].toString() : obj[u"url"_s].toString();
+            bitrate = obj[u"abr"_s].toDouble();
+            headers = obj[u"http_headers"_s].toObject();
+            codec = obj[u"acodec"_s].toString();
+            m_fileSize = obj[u"filesize"_s].toInt();
         }
     }
 
     //fallback
     if(url.isEmpty())
     {
-        for(const QJsonValue &value : json["formats"].toArray())
+        for(const QJsonValue &value : json[u"formats"_s].toArray())
         {
             QJsonObject obj = value.toObject();
 
-            if(obj["abr"].toDouble() > bitrate && obj["vcodec"].toString() == "none")
+            if(obj[u"abr"_s].toDouble() > bitrate && obj[u"vcodec"_s].toString() == "none"_L1)
             {
-                url = obj["protocol"].toString() == "http_dash_segments" ?
-                            obj["fragment_base_url"].toString() : obj["url"].toString();
-
-                bitrate = obj["abr"].toDouble();
-                headers = obj["http_headers"].toObject();
-                codec = obj["acodec"].toString();
-                m_fileSize = obj["filesize"].toInt();
+                url = obj.contains(u"fragment_base_url"_s) ? obj[u"fragment_base_url"_s].toString() : obj[u"url"_s].toString();
+                bitrate = obj[u"abr"_s].toDouble();
+                headers = obj[u"http_headers"_s].toObject();
+                codec = obj[u"acodec"_s].toString();
+                m_fileSize = obj[u"filesize"_s].toInt();
             }
         }
     }
 
     if(url.isEmpty())
     {
-        qWarning("YtbInputSource: unable to find stream");
+        qCWarning(plugin) << "unable to find stream";
         emit error();
         return;
     }
 
-    if(codec != "opus") //disable seeking for other streams
-        m_fileSize = 0;
-
     setProperty(Qmmp::BITRATE, int(bitrate));
     setProperty(Qmmp::FILE_SIZE, m_fileSize);
     setProperty(Qmmp::FORMAT_NAME, codec);
 
-    qDebug() << "YtbInputSource: selected stream:" << codec << bitrate << "kb/s";
-    qDebug("YtbInputSource: downloading stream...");
+    qCDebug(plugin) << "selected stream:" << codec << bitrate << "kb/s";
+    qCDebug(plugin) << "downloading stream...";
 
     QUrl streamUrl(url);
-    //QNetworkRequest request(streamUrl);
     m_request.setUrl(streamUrl);
-    QJsonObject::iterator it = headers.begin();
+    QJsonObject::const_iterator it = headers.begin();
     while (it != headers.end())
     {
         m_request.setRawHeader(it.key().toLatin1(), it.value().toString().toLatin1());
@@ -258,7 +252,7 @@ void YtbInputSource::onProcessFinished(int exitCode, QProcess::ExitStatus status
 
     if(m_offset > 0)
     {
-        m_request.setRawHeader("Range", QString("bytes=%1-").arg(m_offset).toLatin1());
+        m_request.setRawHeader("Range", QStringLiteral("bytes=%1-").arg(m_offset).toLatin1());
         m_request.setAttribute(QNetworkRequest::HttpPipeliningAllowedAttribute, true);
         m_buffer->setOffset(m_offset);
     }
@@ -267,7 +261,7 @@ void YtbInputSource::onProcessFinished(int exitCode, QProcess::ExitStatus status
 
     m_getStreamReply = m_manager->get(m_request);
     m_getStreamReply->setReadBufferSize(0);
-    connect(m_getStreamReply, SIGNAL(downloadProgress(qint64, qint64)), SLOT(onDownloadProgress(qint64,qint64)));
+    connect(m_getStreamReply, &QNetworkReply::downloadProgress, this, &YtbInputSource::onDownloadProgress);
 }
 
 void YtbInputSource::onFinished(QNetworkReply *reply)
@@ -276,7 +270,7 @@ void YtbInputSource::onFinished(QNetworkReply *reply)
     {
         if(reply->error() != QNetworkReply::NoError)
         {
-            qWarning("YtbInputSource: downloading finished with error: %s", qPrintable(reply->errorString()));
+            qCWarning(plugin, "downloading finished with error: %s", qPrintable(reply->errorString()));
             if(!m_ready)
             {
                 emit error();
@@ -286,7 +280,7 @@ void YtbInputSource::onFinished(QNetworkReply *reply)
         else
         {
             m_buffer->addData(m_getStreamReply->readAll());
-            qDebug("YtbInputSource: downloading finished");
+            qCDebug(plugin) << "downloading finished";
         }
 
         m_getStreamReply = nullptr;
@@ -295,14 +289,14 @@ void YtbInputSource::onFinished(QNetworkReply *reply)
     {
         if(reply->error() == QNetworkReply::OperationCanceledError && m_buffer->seekRequestPos() > 0)
         {
-            qDebug("YtbInputSource: processing seek request...");
+            qCDebug(plugin) << "processing seek request...";
             m_buffer->clearRequestPos();
-            m_request.setRawHeader("Range", QString("bytes=%1-").arg(m_offset).toLatin1());
+            m_request.setRawHeader("Range", QStringLiteral("bytes=%1-").arg(m_offset).toLatin1());
             m_request.setAttribute(QNetworkRequest::HttpPipeliningAllowedAttribute, true);
             m_buffer->setOffset(m_offset);
             m_getStreamReply = m_manager->get(m_request);
             m_getStreamReply->setReadBufferSize(0);
-            connect(m_getStreamReply, SIGNAL(downloadProgress(qint64, qint64)), SLOT(onDownloadProgress(qint64,qint64)));
+            connect(m_getStreamReply, &QNetworkReply::downloadProgress, this, &YtbInputSource::onDownloadProgress);
         }
     }
 
@@ -315,7 +309,7 @@ void YtbInputSource::onDownloadProgress(qint64 bytesReceived, qint64 bytesTotal)
 
     if(!m_ready && bytesReceived > PREBUFFER_SIZE)
     {
-        qDebug("YtbInputSource: ready");
+        qCDebug(plugin) << "ready";
         m_ready = true;
         m_buffer->open(QIODevice::ReadOnly);
         emit ready();
@@ -334,7 +328,7 @@ void YtbInputSource::onDownloadProgress(qint64 bytesReceived, qint64 bytesTotal)
 void YtbInputSource::onSeekRequest()
 {
     m_offset = m_buffer->seekRequestPos();
-    qDebug("YtbInputSource: seek request position: %lld", m_offset);
+    qCDebug(plugin) << "seek request position:" << m_offset;
     if(m_getStreamReply)
     {
         QNetworkReply *prevReply = m_getStreamReply;
@@ -344,11 +338,11 @@ void YtbInputSource::onSeekRequest()
     else
     {
         m_buffer->clearRequestPos();
-        m_request.setRawHeader("Range", QString("bytes=%1-").arg(m_offset).toLatin1());
+        m_request.setRawHeader("Range", QStringLiteral("bytes=%1-").arg(m_offset).toLatin1());
         m_request.setAttribute(QNetworkRequest::HttpPipeliningAllowedAttribute, true);
         m_buffer->setOffset(m_offset);
         m_getStreamReply = m_manager->get(m_request);
         m_getStreamReply->setReadBufferSize(0);
-        connect(m_getStreamReply, SIGNAL(downloadProgress(qint64, qint64)), SLOT(onDownloadProgress(qint64,qint64)));
+        connect(m_getStreamReply, &QNetworkReply::downloadProgress, this, &YtbInputSource::onDownloadProgress);
     }
 }
