@@ -67,13 +67,13 @@ static inline void setPixelRGB_ (Pixel *buffer, Uint x, Color c)
     buffer[x].channels.b = c.b;
 }
 
-static inline void getPixelRGB (PluginInfo *goomInfo, Pixel *buffer, Uint x, Uint y, Color * c)
+/*static inline void getPixelRGB (PluginInfo *goomInfo, Pixel *buffer, Uint x, Uint y, Color * c)
 {
     Pixel i = *(buffer + (x + y * goomInfo->screen.width));
     c->b = i.channels.b;
     c->v = i.channels.g;
     c->r = i.channels.r;
-}
+}*/
 
 static inline void getPixelRGB_ (Pixel *buffer, Uint x, Color * c)
 {
